@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2020-12-07
+# Release 2020-12-15
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.4.1
+MAKERESOLVEDEB_VERSION=1.4.2
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -153,7 +153,7 @@ process15() {
     # Create udev rules
     create_directory ${DEB_DIR}/lib/udev/rules.d
     cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
+SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
 EOF
     cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
@@ -255,7 +255,7 @@ process16() {
     # Create udev rules
     create_directory ${DEB_DIR}/lib/udev/rules.d
     cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
+SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
 EOF
     cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
@@ -357,11 +357,13 @@ process17() {
     # Create udev rules
     create_directory ${DEB_DIR}/lib/udev/rules.d
     cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
+SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
 EOF
     cat > ${DEB_DIR}/lib/udev/rules.d/75-davincikb.rules <<EOF
 SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="$attr{bInterfaceNumber}"
+# Editor Keyboard
 SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0b", ENV{.LOCAL_ifNum}=="04", MODE="0666"
+# Speed Editor Keyboard
 SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0e", ENV{.LOCAL_ifNum}=="02", MODE="0666"
 EOF
     cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
